Class: TuiTui::Command::Invalidate
- Inherits:
-
Data
- Object
- Data
- TuiTui::Command::Invalidate
- Defined in:
- lib/tui_tui/command.rb
Overview
Force a full repaint on the next render (e.g. after Ctrl-L).
Force a full repaint on the next render (e.g. after Ctrl-L).